==> cms-db_v0.7.9.tar.gz: admin/commonsettings.php <==
<?php
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */
include('checkuser.inc.php');
checkuser('root');
include('locale.inc.php');
$locale = new LocalizingClass('commonsettings');
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
	<head>
		<title><?php locale('title') ?></title>
		<meta http-equiv="content-type" content="text/html; charset=utf-8" />
		<link rel="stylesheet" type="text/css" href="style.css" />
		<link rel="stylesheet" type="text/css" href="<?php include('mobile.inc.php'); echo mobile() ? 'style-extra-mobile.css' : 'style-extra.css'; ?>" />
	</head>
	<body>

		<h1><?php locale('desc_settings') ?></h1>

		<div class="anchormenu"><span class="leftcorner">&nbsp;</span><ul><li><a href="users.php?<?php echo SID ?>" class="nonewtab"><?php locale('link_usersettings') ?></a></li><li><a href="commonsettings.php?<?php echo SID ?>" class="nonewtab active"><?php locale('link_commonsettings') ?></a></li><li><a href="url.php?<?php echo SID ?>" class="nonewtab"><?php locale('link_urlsettings') ?></a></li><li><a href="adminsettings.php?<?php echo SID ?>" class="nonewtab"><?php locale('link_adminsettings') ?></a></li><li><a href="locale.php?<?php echo SID ?>" class="nonewtab"><?php locale('link_localesettings') ?></a></li></ul><span class="rightcorner">&nbsp;</span></div>

		<?php
		if (isset($_POST['button']) && $_POST['home'] != '') {
			$writethis = '<?php
			$hinweis = "'.$_POST["hinweis"].'";
			$home = "'.$_POST["home"].'";
			$newwindows = "'.$_POST["newwindows"].'";
			$cache = "'.$_POST["cache"].'";
			$xhtml = "'.$_POST["xhtml"].'";
			?>';
			file_put_contents('../data/settings/common.inc.php', $writethis);
			echo '<p class="hint">'.locale('desc_settings-saved',true).'</p>';
			include('cache.inc.php');
			clear_cache_complete();
		}
		include('../data/settings/common.inc.php');
		?>

		<h2><?php locale('title') ?></h2>
		<p>
			<form action="commonsettings.php?<?php echo SID ?>" method="POST">
				<input type="checkbox" name="hinweis" id="hinweis" <?php if ($hinweis == 'on') { echo 'checked="checked"'; }?>>
				<label for="hinweis"><?php locale('desc_poweredby') ?></label><br />
				
				<input type="checkbox" name="newwindows" id="newwindows" <?php if ($newwindows == 'on') { echo 'checked="checked"'; }?>>
				<label for="newwindows"><?php locale('desc_newwindows') ?></label><br />
				
				<label for="home"><?php locale('desc_display-home') ?></label>
				<input type ="text" name="home" id="home" maxlength="99" value="<?php echo $home; ?>" /><br />

				<input type="checkbox" name="xhtml" id="xhtml" <?php if ($xhtml == 'on') { echo 'checked="checked"'; }?>>
				<label for="xhtml"><?php locale('desc_xhtml') ?></label><br />

				<input type="checkbox" name="cache" id="cache" <?php if ($cache == 'on') { echo 'checked="checked"'; }?>>
				<label for="cache"><?php locale('desc_cache') ?></label><br />
				
				<br />
				
				<input type="submit" name="button" value="<?php locale('button_save') ?>">
			</form>
		</p>
		<p style="font-style:italic">
			<?php locale('desc_home-emtpy') ?>
		</p>

	</body>
	</body>
</html>

==> cms-db_v0.7.11.tar.gz: admin/commonsettings.php <==
<?php
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */
include('checkuser.inc.php');
checkuser('root');
include('locale.inc.php');
$locale = new LocalizingClass('commonsettings');
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
	<head>
		<title><?php locale('title') ?></title>
		<meta http-equiv="content-type" content="text/html; charset=utf-8" />
		<link rel="stylesheet" type="text/css" href="style.css" />
		<link rel="stylesheet" type="text/css" href="<?php include('mobile.inc.php'); echo mobile() ? 'style-extra-mobile.css' : 'style-extra.css'; ?>" />
	</head>
	<body>

		<h1><?php locale('desc_settings') ?></h1>

		<div class="anchormenu"><span class="leftcorner">&nbsp;</span><ul><li><a href="users.php?<?php echo SID ?>" class="nonewtab"><?php locale('link_usersettings') ?></a></li><li><a href="commonsettings.php?<?php echo SID ?>" class="nonewtab active"><?php locale('link_commonsettings') ?></a></li><li><a href="url.php?<?php echo SID ?>" class="nonewtab"><?php locale('link_urlsettings') ?></a></li><li><a href="ftpsettings.php?<?php echo SID ?>" class="nonewtab"><?php locale('link_ftpsettings') ?></a></li><li><a href="adminsettings.php?<?php echo SID ?>" class="nonewtab"><?php locale('link_adminsettings') ?></a></li><li><a href="locale.php?<?php echo SID ?>" class="nonewtab"><?php locale('link_localesettings') ?></a></li></ul><span class="rightcorner">&nbsp;</span></div>

		<?php
		include('escape.inc.php');
		if (isset($_POST['button']) && $_POST['home'] != '') {
			$writethis = '<?php
			$hinweis = \''.escapeForm($_POST['hinweis']).'\';
			$home = \''.escapeForm($_POST['home']).'\';
			$newwindows = \''.escapeForm($_POST['newwindows']).'\';
			$cache = \''.escapeForm($_POST['cache']).'\';
			$xhtml = \''.escapeForm($_POST['xhtml']).'\';
			?>';
			file_put_contents('../data/settings/common.inc.php', $writethis);
			echo '<p class="hint">'.locale('desc_settings-saved',true).'</p>';
			include('cache.inc.php');
			clear_cache_complete();
		}
		include('../data/settings/common.inc.php');
		?>

		<h2><?php locale('title') ?></h2>
		<p>
			<form action="commonsettings.php?<?php echo SID ?>" method="POST">
				<label for="home"><?php locale('desc_display-home') ?></label>
				<input type ="text" name="home" id="home" maxlength="99" value="<?php echo htmlspecialchars($home); ?>" /><br />

				<input type="checkbox" name="hinweis" id="hinweis" <?php if ($hinweis == 'on') { echo 'checked="checked"'; }?>>
				<label for="hinweis"><?php locale('desc_poweredby') ?></label><br />

				<input type="checkbox" name="newwindows" id="newwindows" <?php if ($newwindows == 'on') { echo 'checked="checked"'; }?>>
				<label for="newwindows"><?php locale('desc_newwindows') ?></label><br />

				<input type="checkbox" name="xhtml" id="xhtml" <?php if ($xhtml == 'on') { echo 'checked="checked"'; }?>>
				<label for="xhtml"><?php locale('desc_xhtml') ?></label><br />

				<input type="checkbox" name="cache" id="cache" <?php if ($cache == 'on') { echo 'checked="checked"'; }?>>
				<label for="cache"><?php locale('desc_cache') ?></label><br />
				
				<br />
				
				<input type="submit" name="button" value="<?php locale('button_save') ?>">
			</form>
		</p>
		<p style="font-style:italic">
			<?php locale('desc_home-emtpy') ?>
		</p>

	</body>
	</body>
</html>
